diff -ur old/cobbler/action_power.py build/cobbler/action_power.py
--- old/cobbler/action_power.py	2008-11-19 21:09:50.000000000 +0100
+++ build/cobbler/action_power.py	2008-11-20 14:06:49.000000000 +0100
@@ -41,11 +41,13 @@
     Handles conversion of internal state to the tftpboot tree layout
     """
 
-    def __init__(self,system,api,force_user,force_pass):
+    def __init__(self,config,system,api,force_user,force_pass):
         """
         Power library constructor requires a cobbler system object.
         """
         self.system      = system
+        self.config      = config
+        self.settings    = config.settings()
         self.api         = api
         self.force_user  = force_user
         self.force_pass  = force_pass
@@ -121,18 +123,19 @@
         if self.system.power_type in [ "", "none" ]:
             raise CX("Power management is not enabled for this system")
 
+        powerdir=self.settings.power_template_dir
         map = {
-            "bullpap"    : "/etc/cobbler/power_bullpap.template",
-            "apc_snmp"   : "/etc/cobbler/power_apc_snmp.template",
-            "ether-wake" : "/etc/cobbler/power_ether_wake.template",
-            "ipmilan"    : "/etc/cobbler/power_ipmilan.template",
-            "drac"       : "/etc/cobbler/power_drac.template",
-            "ipmitool"   : "/etc/cobbler/power_ipmitool.template",
-            "ipmilan"    : "/etc/cobbler/power_ipmilan.template",
-            "ilo"        : "/etc/cobbler/power_ilo.template",
-            "rsa"        : "/etc/cobbler/power_rsa.template",
-            "lpar"       : "/etc/cobbler/power_lpar.template",
-            "bladecenter": "/etc/cobbler/power_bladecenter.template",
+            "bullpap"    : os.path.join(powerdir,"power_bullpap.template"),
+            "apc_snmp"   : os.path.join(powerdir,"power_apc_snmp.template"),
+            "ether-wake" : os.path.join(powerdir,"power_ether_wake.template"),
+            "ipmilan"    : os.path.join(powerdir,"power_ipmilan.template"),
+            "drac"       : os.path.join(powerdir,"power_drac.template"),
+            "ipmitool"   : os.path.join(powerdir,"power_ipmitool.template"),
+            "ipmilan"    : os.path.join(powerdir,"power_ipmilan.template"),
+            "ilo"        : os.path.join(powerdir,"power_ilo.template"),
+            "rsa"        : os.path.join(powerdir,"power_rsa.template"),
+            "lpar"       : os.path.join(powerdir,"power_lpar.template"),
+            "bladecenter": os.path.join(powerdir,"power_bladecenter.template"),
         }
 
         result = map.get(self.system.power_type, "")
diff -ur old/cobbler/api.py build/cobbler/api.py
--- old/cobbler/api.py	2008-11-19 10:42:29.000000000 +0100
+++ build/cobbler/api.py	2008-11-20 14:08:57.000000000 +0100
@@ -620,13 +620,13 @@
         """
         Powers up a system that has power management configured.
         """
-        return action_power.PowerTool(system,self,user,password).power("on")
+        return action_power.PowerTool(self._config,system,self,user,password).power("on")
 
     def power_off(self, system, user, password):
         """
         Powers down a system that has power management configured.
         """
-        return action_power.PowerTool(system,self,user,password).power("off")
+        return action_power.PowerTool(self._config,system,self,user,password).power("off")
 
     def reboot(self,system, user, password):
         """
diff -ur old/cobbler/pxegen.py build/cobbler/pxegen.py
--- old/cobbler/pxegen.py	2008-11-20 13:36:53.000000000 +0100
+++ build/cobbler/pxegen.py	2008-11-20 14:02:52.000000000 +0100
@@ -261,7 +261,7 @@
         fname = os.path.join(self.bootloc, "pxelinux.cfg", "default")
 
         # read the default template file
-        template_src = open("/etc/cobbler/pxedefault.template")
+        template_src = open(os.path.join(self.settings.pxe_template_dir,"pxedefault.template"))
         template_data = template_src.read()
 
         # sort the profiles
@@ -325,7 +325,7 @@
         metadata = {}
         buffer = ""
 
-        template = "/etc/cobbler/pxeprofile.template"
+        template = os.path.join(self.settings.pxe_template_dir,"pxeprofile.template")
 
         # store variables for templating
         metadata["menu_label"] = "MENU LABEL %s" % os.path.basename(filename)
@@ -394,13 +394,13 @@
         # choose a template
         if system:
             if system.netboot_enabled:
-                template = "/etc/cobbler/pxesystem.template"
+                template = os.path.join(self.settings.pxe_template_dir,"pxesystem.template")
                 if arch == "s390x":
-                    template = "/etc/cobbler/pxesystem_s390x.template"
+                    template = os.path.join(self.settings.pxe_template_dir,"pxesystem_s390x.template")
                 elif arch == "ia64":
-                    template = "/etc/cobbler/pxesystem_ia64.template"
+                    template = os.path.join(self.settings.pxe_template_dir,"pxesystem_ia64.template")
                 elif arch.startswith("ppc"):
-                    template = "/etc/cobbler/pxesystem_ppc.template"
+                    template = os.path.join(self.settings.pxe_template_dir,"pxesystem_ppc.template")
             else:
                 # local booting on ppc requires removing the system-specific dhcpd.conf filename
                 if arch.startswith("ppc"):
@@ -424,9 +424,9 @@
                     # booted off the network, so nothing left to do
                     return None
                 else:
-                    template = "/etc/cobbler/pxelocal.template"
+                    template = os.path.join(self.settings.pxe_template_dir,"pxelocal.template")
         else:
-            template = "/etc/cobbler/pxeprofile.template"
+            template = os.path.join(self.settings.pxe_template_dir,"pxeprofile.template")
 
 
         # now build the kernel command line
diff -ur old/cobbler/settings.py build/cobbler/settings.py
--- old/cobbler/settings.py	2008-11-20 00:28:10.000000000 +0100
+++ build/cobbler/settings.py	2008-11-20 13:56:49.000000000 +0100
@@ -35,7 +35,7 @@
     "allow_duplicate_ips"         : 0,
     "bind_bin"                    : "/usr/sbin/named",
     "cobbler_master"              : '',
-    "default_kickstart"           : "/etc/cobbler/default.ks",
+    "default_kickstart"           : "/var/lib/cobbler/kickstarts/default.ks",
     "default_name_servers"        : '',
     "default_virt_bridge"         : "xenbr0",
     "default_virt_type"           : "auto",
@@ -78,7 +78,9 @@
     "omapi_port"		  : 647,
     "omshell_bin"                 : "/usr/bin/omshell",
     "power_management_default_type" : "ipmitool",
+    "power_template_dir"          : "/etc/cobbler/power",
     "pxe_just_once"               : 0,
+    "pxe_template_dir"            : "/etc/cobbler/pxe",
     "register_new_installs"       : 0,
     "restart_dns"                 : 1,
     "restart_dhcp"                : 1,
